%define build_docs 1

%define major   0
%define libname %mklibname mirisdr %{major}
%define devname %mklibname mirisdr -d

Name:           libmirisdr
Version:        0.0.20130608
Release:        %mkrel 9
Summary:        Support programs for MRi2500
License:        GPLv2
Group:          Communications/Radio
URL:            http://cgit.osmocom.org/libmirisdr/
##TODO Try a more recent fork e.g. https://github.com/ericek111/libmirisdr-5
Source0:        %{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  pkgconfig(libusb)

%if %{build_docs}
BuildRequires:  doxygen
BuildRequires:  texlive-texmf
BuildRequires:  graphviz
%endif

%description
Programs to control the Mirics MRi2500 based DVB dongle in raw mode, so
it can be used as a SDR receiver.

%package -n %{libname}
Summary:        SDR driver for MRi2500
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description -n %{libname}
Library to run Mirics MRi2500 based DVB dongle as a SDR receiver.

%package -n %{devname}
Summary:        Development files for mirisdr
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Library headers and other development files for mirisdr driver.

%package devel-doc
Summary:        Documentation for libmirisdr
Group:          Documentation
BuildArch:      noarch

%description devel-doc
Documentation for libmirisdr driver. HTML and PDF formats.

%prep
%setup -q -n %{name}

# remove buildtime from documentation
sed -i 's|^HTML_TIMESTAMP         = YES|HTML_TIMESTAMP         = NO|' Doxyfile.in

# fix version in .pc
sed -i -e 's,\(^Version:\).*,\1 %{version},' libmirisdr.pc.in

# fix libdir in .pc
sed -i -e 's,\(^set(libdir \\${exec_prefix}/lib\),\1${LIB_SUFFIX},' CMakeLists.txt

%build
%cmake
%cmake_build

#create documentation
%if %{build_docs}
cp Doxyfile.in Doxyfile
sed -i "s\@VERSION@\%{version}\1" Doxyfile
doxygen
cd doc/latex
  make refman.dvi
  dvips -o refman.ps refman.dvi
  ps2pdf refman.ps refman.pdf
cd -
%endif

%install
%cmake_install

rm %{buildroot}%{_libdir}/libmirisdr.a

%ifarch x86_64 aarch64
mv %{buildroot}/usr/lib/pkgconfig %{buildroot}%{_libdir}
%endif

#install udev rules
install -Dpm644 mirisdr.rules %{buildroot}%{_udevrulesdir}/10-mirisdr.rules

#install documentation
%if %{build_docs}
mkdir -p %{buildroot}%{_docdir}/%{name}/pdf
cp -r doc/html %{buildroot}%{_docdir}/%{name}
cp -r doc/latex/*.pdf %{buildroot}%{_docdir}/%{name}/pdf
%endif

%files
%doc AUTHORS README
%{_bindir}/miri_*
%{_udevrulesdir}/10-mirisdr.rules
%if %{build_docs}
%exclude %{_docdir}/%{name}/html
%exclude %{_docdir}/%{name}/pdf
%endif

%files -n %{libname}
%{_libdir}/libmirisdr.so.%{major}{,.*}

%files -n %{devname}
%{_libdir}/libmirisdr.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/libmirisdr.pc

%if %{build_docs}
%files devel-doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/html
%{_docdir}/%{name}/pdf
%endif


%changelog
* Mon Dec 12 2022 ghibo <ghibo> 0.0.20130608-9.mga9
+ Revision: 1921300
- Fix building (workaround for doxygen 1.9.5 bug)

* Thu Mar 31 2022 umeabot <umeabot> 0.0.20130608-8.mga9
+ Revision: 1836582
- Mageia 9 Mass Rebuild

* Thu Feb 13 2020 daviddavid <daviddavid> 0.0.20130608-7.mga8
+ Revision: 1515135
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.0.20130608-6.mga7
+ Revision: 1298996
- Mageia 7 Mass Rebuild

* Sat Jun 23 2018 wally <wally> 0.0.20130608-5.mga7
+ Revision: 1239223
- fix libdir in pkgconf .pc file
- fix version in pkgconf .pc file

* Sat Jun 23 2018 wally <wally> 0.0.20130608-4.mga7
+ Revision: 1239188
- fix build on aarch64

* Tue Feb 09 2016 umeabot <umeabot> 0.0.20130608-3.mga6
+ Revision: 952137
- Mageia 6 Mass Rebuild

* Fri Jan 16 2015 barjac <barjac> 0.0.20130608-2.mga5
+ Revision: 810917
- devel-doc should not require -devel
- remove COPYING

* Thu Jan 15 2015 barjac <barjac> 0.0.20130608-1.mga5
+ Revision: 810863
- New package based loosely on suse/fedora with thanks

